#! /bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/dhcpd_debug-update.sh - paramater update script
#
# Creation   : 2011-05-20 root
# Last update: $Id: dhcpd_debug-update.sh 58203 2018-09-30 20:36:55Z hbfl $
#
# Copyright (c) 2011 Maximilian Pasternak, max(dot)eisfair(at)bluescreen(dot)de
# Copyright (c) 2018-2019 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# Include configlib for using printvar
. /var/install/include/configlib

# Set package name
package_name=dhcpd_debug

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
get_defaults()
{
    VERSION=$(sed -n '/<version>/ s# ##g; s#</*version>##gp' \
              /var/install/packages/${package_name})

    DHCPD_DEBUG_DAEMON_TRACE='no'
    DHCPD_DEBUG_SCRIPTS_TRACE='no'
    DHCPD_DEBUG_SCRIPTS_TRACE_EXT='no'
    DHCPD_DEBUG_SCRIPTS_TESTMODE='no'
}

# ---------------------------------------------------------------------------
# read old configuration and rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
# read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl --conf ${package_name} '2011-05-22' 'max'
    # ------------------------------------------------------------------------
    echo "# DHCPD_DEBUG-${VERSION}"
    # ------------------------------------------------------------------------
    printgroup 'Activate Debugging and Tracing'
    # ------------------------------------------------------------------------
    printvar 'DHCPD_DEBUG_DAEMON_TRACE' 'Use: yes or no'
    printvar 'DHCPD_DEBUG_SCRIPTS_TRACE' 'Use: yes or no'
    printvar 'DHCPD_DEBUG_SCRIPTS_TRACE_EXT' 'Use: yes or no'
    printvar 'DHCPD_DEBUG_SCRIPTS_TESTMODE' 'Use: yes or no'

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
make_check_file()
{
    printgpl --check ${package_name} '2011-05-20' 'max' >/etc/check.d/${package_name}
    cat >> /etc/check.d/${package_name} <<EOFG
# Variable                      OPT_VARIABLE       VARIABLE_N         VALUE

DHCPD_DEBUG_DAEMON_TRACE        -                  -                  YESNO
DHCPD_DEBUG_SCRIPTS_TRACE       -                  -                  YESNO
DHCPD_DEBUG_SCRIPTS_TRACE_EXT   -                  -                  YESNO
DHCPD_DEBUG_SCRIPTS_TESTMODE    -                  -                  YESNO

EOFG

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}


    printgpl --check_ext ${package_name} '2011-05-20' 'root' >/etc/check.d/${package_name}.ext
    cat >> /etc/check.d/${package_name}.ext <<EOFG
if (DHCPD_DEBUG_SCRIPTS_TESTMODE == "yes")
then
    warning "SCRIPTS_TESTMODE is enables and therefore config changes won't be applied!"
fi

EOFG

    # Set rights for check.ext file
    chmod 0600 /etc/check.d/${package_name}.ext
    chown root /etc/check.d/${package_name}.ext
}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}
    
    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file
    
    exit 0
}
   
# ---------------------------------------------------------------------------
# call function main
# ---------------------------------------------------------------------------
main "${@}"

# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
